summaryrefslogtreecommitdiff
path: root/src/bookmarks.h
diff options
context:
space:
mode:
authorAlexandr Domrachev <alexandr.domrachev@gmail.com>2009-04-27 17:05:43 +0000
committerAlexandr Domrachev <alexandr.domrachev@gmail.com>2009-04-27 17:05:43 +0000
commitfdbd70a77a8c294e0a578073c738f3bc4dfa6ab5 (patch)
tree4f3a93b0b7b3fe85065e4456865382fec244928f /src/bookmarks.h
parent.gitignore update (diff)
downloadrekonq-fdbd70a77a8c294e0a578073c738f3bc4dfa6ab5.tar.xz
Some changes ported for merge to mainline (bookmarks & links handling related)
Added author: me :) Bookmark owner: openFolderinTabs implemented Links handling ported from Pawel branch Issue #1 fixed
Diffstat (limited to 'src/bookmarks.h')
-rw-r--r--src/bookmarks.h49
1 files changed, 32 insertions, 17 deletions
diff --git a/src/bookmarks.h b/src/bookmarks.h
index 5ac1270d..32982c8a 100644
--- a/src/bookmarks.h
+++ b/src/bookmarks.h
@@ -23,6 +23,9 @@
#ifndef BOOKMARKS_H
#define BOOKMARKS_H
+// Local includes
+#include "application.h"
+
// Qt Includes
#include <QWidget>
@@ -69,8 +72,8 @@ public:
* @param mouseButtons the mouse buttons clicked to select the bookmark
* @param keyboardModifiers the keyboard modifiers pushed when the bookmark was selected
*/
- virtual void openBookmark(const KBookmark &bookmark,
- Qt::MouseButtons mouseButtons,
+ virtual void openBookmark(const KBookmark &bookmark,
+ Qt::MouseButtons mouseButtons,
Qt::KeyboardModifiers keyboardModifiers);
@@ -95,14 +98,23 @@ public:
*/
virtual bool supportsTabs() const { return true; }
+ /**
+ * Called if the user wants to open every bookmark in this folder in a new tab.
+ * The default implementation does nothing.
+ * This is only called if supportsTabs() returns true
+ */
+ virtual void openFolderinTabs(const KBookmarkGroup &bm);
+
signals:
/**
* This signal is emitted when an url has to be loaded
*
* @param url the URL to load
+ * @param type type of load
+ * @see Application::OpenType
*
*/
- void openUrl(const KUrl &);
+ void openUrl(const KUrl &url, Rekonq::OpenType type);
private:
@@ -124,17 +136,17 @@ class BookmarkMenu : public KBookmarkMenu
Q_OBJECT
public:
- BookmarkMenu(KBookmarkManager* manager,
- KBookmarkOwner* owner,
- KMenu* menu,
+ BookmarkMenu(KBookmarkManager* manager,
+ KBookmarkOwner* owner,
+ KMenu* menu,
KActionCollection* actionCollection);
~BookmarkMenu();
-
+
virtual KMenu *viewContextMenu(QAction* action);
-
+
protected slots:
void slotAddBookmark();
-
+
};
@@ -163,7 +175,7 @@ public:
*/
BookmarkProvider(QWidget* parent=0);
~BookmarkProvider();
-
+
/**
* @short Get the Bookmarks Menu Action
* @return the Bookmarks Menu
@@ -189,11 +201,14 @@ public:
signals:
/**
- * @short This signal is emitted when an url has to be loaded
- *
- * @param url the URL to load
- */
- void openUrl(const KUrl &url);
+ * This signal is emitted when an url has to be loaded
+ *
+ * @param url the URL to load
+ * @param type type of load
+ * @see Application::OpenType
+ *
+ */
+ void openUrl(const KUrl &url, Rekonq::OpenType type);
public slots:
@@ -202,12 +217,12 @@ public slots:
* @param point Point on whitch you want to open this menu
*/
void contextMenu(const QPoint &point);
-
+
/**
* @short Waits for signal that the group with the address has been modified by the caller.
* Waits for signal that the group (or any of its children) with the address
* @p groupAddress (e.g. "/4/5") has been modified by the caller @p caller.
- *
+ *
* @param group bookmark group adress
* @param caller caller that modified the bookmarks
* @see KBookmarkManager::changed